# Django API Reference

## Model

::: yoro.django.models.GeoAltiusCode
    options:
      show_root_heading: true

## Services

::: yoro.django.services
    options:
      show_root_heading: false

## Views

::: yoro.django.views
    options:
      show_root_heading: false
